@@ -57,11 +57,12 @@
 #include <QNetworkAccessManager>
 
 #include <glib.h>
+#include <QRegularExpression>
 #include "FlatpakSourcesBackend.h"
 
 DISCOVER_BACKEND_PLUGIN(FlatpakBackend)
 
-static QString idForInstalledRef(FlatpakInstallation *installation, FlatpakInstalledRef *ref)
+static FlatpakResource::Id idForInstalledRef(FlatpakInstallation *installation, FlatpakInstalledRef *ref)
 {
     const FlatpakResource::ResourceType appType = flatpak_ref_get_kind(FLATPAK_REF(ref)) == FLATPAK_REF_KIND_APP ? FlatpakResource::DesktopApp : FlatpakResource::Runtime;
     const QString name = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
@@ -70,8 +71,7 @@ static QString idForInstalledRef(FlatpakInstallation *installation, FlatpakInsta
     const QString arch = QString::fromUtf8(flatpak_ref_get_arch(FLATPAK_REF(ref)));
     const QString branch = QString::fromUtf8(flatpak_ref_get_branch(FLATPAK_REF(ref)));
 
-    return QStringLiteral("%1/%2/%3/%4/%5/%6").arg(FlatpakResource::installationPath(installation), QLatin1String("flatpak"), QString::fromUtf8(flatpak_installed_ref_get_origin(ref)),
-                                                   FlatpakResource::typeAsString(appType), appId, branch);
+    return { installation, QString::fromUtf8(flatpak_installed_ref_get_origin(ref)), appType, appId, branch, arch };
 }
 
 FlatpakBackend::FlatpakBackend(QObject* parent)
@@ -101,6 +101,7 @@ FlatpakBackend::FlatpakBackend(QObject* parent)
 
 FlatpakBackend::~FlatpakBackend()
 {
+    g_cancellable_cancel(m_cancellable);
     m_threadPool.clear();
     for(auto inst : m_installations)
         g_object_unref(inst);
@@ -225,16 +226,18 @@ FlatpakResource * FlatpakBackend::getRuntimeForApp(FlatpakResource *resource) co
         return runtime;
     }
 
-    const QString runtimeId = QStringLiteral("runtime/") + runtimeInfo.at(0) + QLatin1Char('/') + runtimeInfo.at(2);
-
     for(auto it = m_resources.constBegin(), itEnd = m_resources.constEnd(); it!=itEnd; ++it) {
-        if (it.key().endsWith(runtimeId)) {
+        const auto id = it.key();
+        if (id.type == FlatpakResource::Runtime && id.id == runtimeInfo.at(0) && id.branch == runtimeInfo.at(2)) {
             runtime = *it;
             break;
         }
     }
 
     // TODO if runtime wasn't found, create a new one from available info
+    if (!runtime) {
+        qWarning() << "could not find runtime" << runtimeInfo << resource;
+    }
 
     return runtime;
 }
@@ -365,7 +368,7 @@ FlatpakResource * FlatpakBackend::addAppFromFlatpakRef(const QUrl &url)
     QSettings settings(url.toLocalFile(), QSettings::NativeFormat);
     const QString refurl = settings.value(QStringLiteral("Flatpak Ref/Url")).toString();
 
-    g_autoptr(GError) error = NULL;
+    g_autoptr(GError) error = nullptr;
     g_autoptr(FlatpakRemoteRef) remoteRef = nullptr;
     {
         QFile f(url.toLocalFile());
@@ -512,11 +515,6 @@ void FlatpakBackend::addResource(FlatpakResource *resource)
     m_resources.insert(resource->uniqueId(), resource);
 }
 
-bool FlatpakBackend::compareAppFlatpakRef(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource, FlatpakInstalledRef *ref) const
-{
-    return resource->uniqueId() == idForInstalledRef(flatpakInstallation, ref);
-}
-
 class FlatpakSource
 {
 public:
@@ -730,10 +728,9 @@ void FlatpakBackend::loadLocalUpdates(FlatpakInstallation *flatpakInstallation)
 void FlatpakBackend::loadRemoteUpdates(FlatpakInstallation* installation)
 {
     auto fw = new QFutureWatcher<GPtrArray *>(this);
-    fw->setFuture(QtConcurrent::run(&m_threadPool, [installation]() -> GPtrArray * {
-        g_autoptr(GCancellable) cancellable = g_cancellable_new();
+    fw->setFuture(QtConcurrent::run(&m_threadPool, [installation, this]() -> GPtrArray * {
         g_autoptr(GError) localError = nullptr;
-        GPtrArray *refs = flatpak_installation_list_installed_refs_for_update(installation, cancellable, &localError);
+        GPtrArray *refs = flatpak_installation_list_installed_refs_for_update(installation, m_cancellable, &localError);
         if (!refs) {
             qWarning() << "Failed to get list of installed refs for listing updates: " << localError->message;
         }
@@ -933,21 +930,14 @@ bool FlatpakBackend::updateAppMetadata(FlatpakResource *resource, const QString
 
 bool FlatpakBackend::updateAppMetadata(FlatpakResource *resource, const QByteArray &data)
 {
-    // Save the content to temporary file
-    QTemporaryFile tempFile;
-    tempFile.setAutoRemove(false);
-    if (!tempFile.open()) {
-        qWarning() << "Failed to get metadata file";
+    //We just find the runtime with a regex, QSettings only can read from disk (and so does KConfig)
+    const QRegularExpression rx(QStringLiteral("runtime=(.*)"));
+    const auto match = rx.match(QString::fromUtf8(data));
+    if (!match.isValid()) {
         return false;
     }
 
-    tempFile.write(data);
-    tempFile.close();
-
-    updateAppMetadata(resource, tempFile.fileName());
-
-    tempFile.remove();
-
+    resource->setRuntime(match.captured(1));
     return true;
 }
 
