@@ -76,15 +76,15 @@ public:
     QString displayName() const override;
     bool hasApplications() const override;
     FwupdClient *client;
-    
+
     bool downloadFile(const QUrl &uri, const QString &filename);
-    bool refreshRemotes(uint cacheAge);
-    bool refreshRemote(FwupdRemote *remote, uint cacheAge);
-    const QUrl cacheFile(const QString &kind, const QFileInfo &resource);
+    void refreshRemotes(uint cacheAge);
+    void refreshRemote(FwupdRemote *remote, uint cacheAge);
+    QString cacheFile(const QString &kind, const QString &baseName);
     FwupdResource * createDevice(FwupdDevice *device);
     FwupdResource * createRelease(FwupdDevice *device);
     FwupdResource * createApp(FwupdDevice *device);
-    QByteArray getChecksum(const QUrl filename, QCryptographicHash::Algorithm hashAlgorithm);
+    QByteArray getChecksum(const QString &filename, QCryptographicHash::Algorithm hashAlgorithm);
     QString buildDeviceID(FwupdDevice* device);
     void addUpdates();
     void addResourceToList(FwupdResource *res);
@@ -94,22 +94,18 @@ public:
     void handleError(GError **perror);
     QSet<AbstractResource*> getAllUpdates();
     QString getAppName(QString ID);
-    QMap<GChecksumType,QCryptographicHash::Algorithm> initHashMap();
+    QMap<GChecksumType,QCryptographicHash::Algorithm> gchecksumToQChryptographicHash();
 
 
 public Q_SLOTS:
-    void toggleFetching();
-
-private Q_SLOTS:
-    void saveFile(QNetworkReply *reply);
+    void refresh();
 
 private:
-    void populate(const QString& name);
+    void populate();
 
     QHash<QString, FwupdResource*> m_resources;
-    QMap<QUrl,QString> m_downloadFile;
     StandardBackendUpdater* m_updater;
-    bool m_fetching;
+    bool m_fetching = false;
     int m_startElements;
     QList<AbstractResource*> m_toUpdate;
 };
