@@ -33,7 +33,7 @@ FwupdResource::FwupdResource(QString name, bool isTechnical, AbstractResourcesBa
     , m_state(State::Broken)
     , m_isTechnical(isTechnical)
 {
-
+    setObjectName(m_name);
 }
 
 QList<PackageState> FwupdResource::addonsInformation()
@@ -56,10 +56,6 @@ QStringList FwupdResource::categories()
    return m_categories;
 }
 
-void FwupdResource::addCategories(const QString &category){
-    m_categories.append(category);
-}
-
 QString FwupdResource::comment()
 {
     return m_summary;
@@ -151,16 +147,16 @@ void FwupdResource::fetchChangelog()
 void FwupdResource::setState(AbstractResource::State state)
 {
     if(m_state != state)
-    {   
+    {
         m_state = state;
         emit stateChanged();
     }
-        
+
 }
 
 void FwupdResource::setAddons(const AddonList& addons)
 {
-    Q_FOREACH(const QString& toInstall, addons.addonsToInstall()) 
+    Q_FOREACH(const QString& toInstall, addons.addonsToInstall())
     {
         setAddonInstalled(toInstall, true);
     }
