@@ -27,6 +27,7 @@
 #include <QAction>
 #include <QProcess>
 #include <QDebug>
+#include <QRegularExpression>
 #include <resources/AbstractResourcesBackend.h>
 #include "PackageKitBackend.h"
 #include "config-paths.h"
@@ -41,18 +42,10 @@ public:
     QHash<int, QByteArray> roleNames() const override
     {
         auto roles = QStandardItemModel::roleNames();
-        roles[AbstractSourcesBackend::SourcesBackend] = "sourcesBackend";
         roles[Qt::CheckStateRole] = "checked";
         return roles;
     }
 
-    QVariant data(const QModelIndex & index, int role) const override {
-        if (role == AbstractSourcesBackend::SourcesBackend)
-            return QVariant::fromValue<QObject*>(m_backend);
-        else
-            return QStandardItemModel::data(index, role);
-    }
-
     bool setData(const QModelIndex & index, const QVariant & value, int role) override {
         auto item = itemFromIndex(index);
         if (!item)
@@ -60,7 +53,7 @@ public:
 
         switch(role) {
             case Qt::CheckStateRole: {
-                auto transaction = PackageKit::Daemon::global()->repoEnable(item->text(), value.toInt() == Qt::Checked);
+                auto transaction = PackageKit::Daemon::global()->repoEnable(item->data(AbstractSourcesBackend::IdRole).toString(), value.toInt() == Qt::Checked);
                 connect(transaction, &PackageKit::Transaction::errorCode, m_backend, &PackageKitSourcesBackend::transactionError);
                 return true;
             }
@@ -79,6 +72,7 @@ static QAction* createActionForService(const QString &servicePath, QObject* pare
     KDesktopFile parser(servicePath);
     action->setIcon(QIcon::fromTheme(parser.readIcon()));
     action->setText(parser.readName());
+    action->setToolTip(parser.readComment());
     QObject::connect(action, &QAction::triggered, action, [servicePath](){
         bool b = QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {servicePath});
         if (!b)
@@ -95,14 +89,20 @@ PackageKitSourcesBackend::PackageKitSourcesBackend(AbstractResourcesBackend* par
     resetSources();
 
     // Kubuntu-based
-    auto service = PackageKitBackend::locateService(QStringLiteral("software-properties-kde.desktop"));
-    if (!service.isEmpty())
-        m_actions += createActionForService(service, this);
+    auto addNativeSourcesManager = [this](const QString &file){
+        auto service = PackageKitBackend::locateService(file);
+        if (!service.isEmpty())
+            m_actions += createActionForService(service, this);
+        };
 
-    // openSUSE-based
-    service = PackageKitBackend::locateService(QStringLiteral("YaST2/sw_source.desktop"));
-    if (!service.isEmpty())
-        m_actions += createActionForService(service, this);
+    //New Ubuntu
+    addNativeSourcesManager(QStringLiteral("software-properties-qt.desktop"));
+
+    //Old Ubuntu
+    addNativeSourcesManager(QStringLiteral("software-properties-kde.desktop"));
+
+    //OpenSuse
+    addNativeSourcesManager(QStringLiteral("YaST2/sw_source.desktop"));
 }
 
 QString PackageKitSourcesBackend::idDescription()
@@ -114,7 +114,7 @@ QStandardItem* PackageKitSourcesBackend::findItemForId(const QString &id) const
 {
     for(int i=0, c=m_sources->rowCount(); i<c; ++i) {
         auto it = m_sources->item(i);
-        if (it->text() == id)
+        if (it->data(AbstractSourcesBackend::IdRole).toString() == id)
             return it;
     }
     return nullptr;
@@ -126,9 +126,20 @@ void PackageKitSourcesBackend::addRepositoryDetails(const QString &id, const QSt
     QStandardItem* item = findItemForId(id);
 
     if (!item) {
-        item = new QStandardItem(id);
+        QString desc = description;
+        if (PackageKit::Daemon::backendName() == QLatin1String("aptcc")) {
+            QRegularExpression exp(QStringLiteral("^/etc/apt/sources.list.d/(.+?).list:.*"));
+
+            auto matchIt = exp.globalMatch(id);
+            if (matchIt.hasNext()) {
+                auto match = matchIt.next();
+                desc += QStringLiteral(" - ") + match.captured(1);
+            }
+        }
+        item = new QStandardItem(desc);
         add = true;
     }
+    item->setData(id, IdRole);
     item->setCheckState(enabled ? Qt::Checked : Qt::Unchecked);
 
     if (add)
