@@ -182,8 +182,8 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
         if (!toremove.isEmpty()) {
             const auto toinstall = QStringList() << m_packagesModified.value(PackageKit::Transaction::InfoInstalling) << m_packagesModified.value(PackageKit::Transaction::InfoUpdating);
             Q_EMIT proceedRequest(i18n("Packages to remove"), i18n("The following packages will be removed by the update:\n<ul><li>%1</li></ul>\nin order to install:\n<ul><li>%2</li></ul>",
-                                                                   PackageKitResource::joinPackages(toremove, QStringLiteral("</li><li>")),
-                                                                   PackageKitResource::joinPackages(toinstall, QStringLiteral("</li><li>"))
+                                                                   PackageKitResource::joinPackages(toremove, QStringLiteral("</li><li>"), {}),
+                                                                   PackageKitResource::joinPackages(toinstall, QStringLiteral("</li><li>"), {})
                                                                   ));
         } else {
             proceed();
