@@ -28,6 +28,7 @@
 #include <QVector>
 #include <QCollatorSortKey>
 #include <QJsonObject>
+#include <QDate>
 
 #include "discovercommon_export.h"
 #include "PackageState.h"
@@ -56,6 +57,9 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QStringList category READ categories CONSTANT)
     Q_PROPERTY(bool isTechnical READ isTechnical CONSTANT)
     Q_PROPERTY(QUrl homepage READ homepage CONSTANT)
+    Q_PROPERTY(QUrl helpURL READ helpURL CONSTANT)
+    Q_PROPERTY(QUrl bugURL READ bugURL CONSTANT)
+    Q_PROPERTY(QUrl donationURL READ donationURL CONSTANT)
     Q_PROPERTY(bool canUpgrade READ canUpgrade NOTIFY stateChanged)
     Q_PROPERTY(bool isInstalled READ isInstalled NOTIFY stateChanged)
     Q_PROPERTY(QString license READ license CONSTANT)
@@ -73,6 +77,9 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString appstreamId READ appstreamId CONSTANT)
     Q_PROPERTY(QString categoryDisplay READ categoryDisplay CONSTANT)
     Q_PROPERTY(QUrl url READ url CONSTANT)
+    Q_PROPERTY(QString executeLabel READ executeLabel CONSTANT)
+    Q_PROPERTY(QString sourceIcon READ sourceIcon CONSTANT)
+    Q_PROPERTY(QDate releaseDate READ releaseDate NOTIFY stateChanged)
     public:
         /**
          * This describes the state of the resource
@@ -107,7 +114,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
         virtual QString packageName() const = 0;
 
         ///resource name to be displayed
-        virtual QString name() = 0;
+        virtual QString name() const = 0;
 
         ///short description of the resource
         virtual QString comment() = 0;
@@ -122,11 +129,17 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
         ///executes the resource, if applies.
         Q_SCRIPTABLE virtual void invokeApplication() const = 0;
 
-        virtual State state() const = 0;
+        virtual State state() = 0;
 
         virtual QStringList categories() = 0;
-        ///@returns a URL that points to the content
-        virtual QUrl homepage() = 0;
+        ///@returns a URL that points to the app's website
+        virtual QUrl homepage();
+        ///@returns a URL that points to the app's online documentation
+        virtual QUrl helpURL();
+        ///@returns a URL that points to the place where you can file a bug
+        virtual QUrl bugURL();
+        ///@returns a URL that points to the place where you can donate money to the app developer
+        virtual QUrl donationURL();
 
         virtual bool isTechnical() const;
 
@@ -154,8 +167,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
         void addMetadata(const QString &key, const QJsonValue &value);
         QJsonValue getMetadata(const QString &key);
 
-        bool canUpgrade() const;
-        bool isInstalled() const;
+        bool canUpgrade();
+        bool isInstalled();
 
         ///@returns a user-readable explaination of the resource status
         ///by default, it will specify what state() is returning
@@ -189,6 +202,13 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
          */
         virtual QUrl url() const;
 
+        virtual QString executeLabel() const;
+        virtual QString sourceIcon() const = 0;
+        /**
+         * @returns the date of the resource's most recent release
+         */
+        virtual QDate releaseDate() const = 0;
+
     public Q_SLOTS:
         virtual void fetchScreenshots();
         virtual void fetchChangelog() = 0;
