@@ -25,32 +25,32 @@
 #include <QSet>
 #include <KConcatenateRowsProxyModel>
 #include "discovercommon_export.h"
-
-class QAction;
-class AbstractSourcesBackend;
-class AbstractResourcesBackend;
-class SourceBackendModel;
+#include "AbstractSourcesBackend.h"
 
 class DISCOVERCOMMON_EXPORT SourcesModel : public KConcatenateRowsProxyModel
 {
     Q_OBJECT
     public:
         enum Roles {
-            SourcesBackend = Qt::UserRole+1,
-            SourceNameRole,
+            SourceNameRole = AbstractSourcesBackend::LastRole,
+            SourcesBackend,
             ResourcesBackend
         };
         Q_ENUM(Roles)
 
         explicit SourcesModel(QObject* parent = nullptr);
         ~SourcesModel() override;
-
+        
         static SourcesModel* global();
         QVariant data(const QModelIndex & index, int role) const override;
         QHash<int, QByteArray> roleNames() const override;
 
-        SourceBackendModel* addBackend(AbstractResourcesBackend* backend);
         void addSourcesBackend(AbstractSourcesBackend* sources);
+
+        Q_SCRIPTABLE AbstractSourcesBackend* sourcesBackendByName(const QString &name) const;
+
+    private:
+        const QAbstractItemModel* modelAt(const QModelIndex& idx) const;
 };
 
 #endif // SOURCESMODEL_H
