@@ -73,14 +73,44 @@ static int kIndexOf(const Q& list, W func)
     return -1;
 }
 
+template <typename T>
+static QVector<T> kSetToVector(const QSet<T> & set)
+{
+    QVector<T> ret;
+    ret.reserve(set.size());
+    for(auto &x: set)
+        ret.append(x);
+    return ret;
+}
+
+template <typename T>
+static QSet<T> kVectorToSet(const QVector<T> & set)
+{
+    QSet<T> ret;
+    ret.reserve(set.size());
+    for(auto &x: set)
+        ret.insert(x);
+    return ret;
+}
+
 class ElapsedDebug : private QElapsedTimer
 {
 public:
     ElapsedDebug(const QString &name = QStringLiteral("<unnamed>")) : m_name(name) { start(); }
     ~ElapsedDebug() { qDebug("elapsed %s: %lld!", m_name.toUtf8().constData(), elapsed()); }
-    void step(const QString &step) { qDebug("step(%s) %s: %lld!", qPrintable(step), m_name.toUtf8().constData(), elapsed()); }
+    void step(const QString &step) { qDebug("step %s(%s): %lld!", m_name.toUtf8().constData(), qPrintable(step), elapsed()); }
 
     QString m_name;
 };
 
+class CallOnDestroy : public QObject
+{
+public:
+    CallOnDestroy(std::function<void()> f) : m_func(std::move(f)) {}
+    ~CallOnDestroy() { m_func(); }
+
+private:
+    std::function<void()> m_func;
+};
+
 #endif
